Hacker en Charge

×

## Articles du Code Pénal

Article 323-1
Constitue une infraction pénale le fait d'accéder ou de se maintenir, frauduleusement, dans tout ou partie d'un système de traitement automatisé de données.
Peine : Jusqu'à 2 ans d'emprisonnement et 60 000 euros d'amende.
Article 323-3
Le fait d'introduire frauduleusement des données, des informations ou des commandes dans un système de traitement automatisé de données est puni de cinq ans d'emprisonnement et de 150 000 euros d'amende.
Peine : Jusqu'à 5 ans d'emprisonnement et 150 000 euros d'amende.
Article 226-16
Est puni d'un an d'emprisonnement et de 45 000 euros d'amende le fait, par quelque moyen que ce soit, de porter atteinte à l'intimité de la vie privée d'autrui en captant, enregistrant ou transmettant, sans le consentement de leur auteur, des paroles prononcées à titre privé ou confidentiel.
Peine : Jusqu'à 1 an d'emprisonnement et 45 000 euros d'amende.
Pour plus de détails, consultez Article 323-1, Article 323-3, et Article 226-16.

Alarme déclenchée !